**The package is of alpha currently**

noopy.folio is a library that works on financial portfolios including assessment, optimization and etc.

noopy.folio is a subpackage that can be installed alone under the root package name "noopy"

Design principles:
- open minded
- model driven
